#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-hlint-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-hlint-plugin-2.3.0.0-47fXrlGrpMy8DWkSJSd3MO
key:                  hls-hlint-plugin-2.3.0.0-47fXrlGrpMy8DWkSJSd3MO
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           atreyu.bbb@gmail.com
author:               The Haskell IDE Team
synopsis:             Hlint integration plugin with Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  747484642ff4fe29e0cdc8b530ac5d2b
exposed:              True
exposed-modules:      Ide.Plugin.Hlint
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-hlint-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-hlint-plugin
hs-libraries:         HShls-hlint-plugin-2.3.0.0-47fXrlGrpMy8DWkSJSd3MO
depends:
    Diff-1.0-Lm5Fw8fjuFK17wB6yKmBme
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    apply-refact-0.14.0.0-2XK6AUySDue2vFeun3S80K base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-CRQVneoi5B7He0Tx6HSYSU deepseq-1.4.8.1
    directory-1.3.8.5 extra-1.7.16-92gEBqN3yIpF5We3DBC4D
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-GibOHdaOmEHKz6gt8mkn0G
    ghc-lib-parser-ex-9.6.0.2-BZomHo0USkDG5AmNude0lH
    ghcide-2.3.0.0-JSspKOqlahaAwnXaTGGrov
    hashable-1.4.7.0-4qZi9v5WFMZ3p1WVFpevAr
    hlint-3.6.1-L1EOhVArr46LGmLyNYe130
    hls-plugin-api-2.3.0.0-HSJ5IykGHJrE42B9MfY8EV
    lens-5.3.4-FoS34BQg8yPHQoAczDydbc
    lsp-2.2.0.0-9lJlGvT5rLo8cal3T7PXHz mtl-2.3.1
    refact-0.3.0.2-FJtsqxURVxtCj2G2lOYVeD
    regex-tdfa-1.3.2.5-GDcLEW3RNnhJam1iRhMaaH stm-2.5.1.0
    temporary-1.3-HWoowl2obdSCRTCICKYJCV text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp

haddock-interfaces:
    /usr/share/doc/haskell-hls-hlint-plugin/html/hls-hlint-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-hlint-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

